[Xenomai-git] Philippe Gerum : cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

2016-09-29 Thread git repository hosting
Module: xenomai-3
Branch: wip/drivers
Commit: 2856ff3c0c6199352fac11b4c6dab07a6e8b7b3b
URL:
http://git.xenomai.org/?p=xenomai-3.git;a=commit;h=2856ff3c0c6199352fac11b4c6dab07a6e8b7b3b

Author: Philippe Gerum 
Date:   Thu Sep  8 16:29:44 2016 +0200

cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

---

 kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h |2 --
 kernel/cobalt/arch/powerpc/thread.c |6 +++---
 2 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h 
b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
index 8d6be84..1de5cac 100644
--- a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
+++ b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
@@ -93,8 +93,6 @@ static inline int xnarch_escalate(void)
 
 void xnarch_switch_to(struct xnthread *out, struct xnthread *in);
 
-void xnarch_save_fpu(struct xnthread *thread);
-
 void xnarch_switch_fpu(struct xnthread *from, struct xnthread *thread);
 
 #endif /* !_COBALT_POWERPC_ASM_THREAD_H */
diff --git a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h 
b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
index 8d6be84..1de5cac 100644
--- a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
+++ b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
@@ -93,8 +93,6 @@ static inline int xnarch_escalate(void)
 
 void xnarch_switch_to(struct xnthread *out, struct xnthread *in);
 
-void xnarch_save_fpu(struct xnthread *thread);
-
 void xnarch_switch_fpu(struct xnthread *from, struct xnthread *thread);
 
 #endif /* !_COBALT_POWERPC_ASM_THREAD_H */
diff --git a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h 
b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
index 8d6be84..1de5cac 100644
--- a/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
+++ b/kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h
@@ -93,8 +93,6 @@ static inline int xnarch_escalate(void)
 
 void xnarch_switch_to(struct xnthread *out, struct xnthread *in);
 
-void xnarch_save_fpu(struct xnthread *thread);
-
 void xnarch_switch_fpu(struct xnthread *from, struct xnthread *thread);
 
 #endif /* !_COBALT_POWERPC_ASM_THREAD_H */
diff --git a/kernel/cobalt/arch/powerpc/thread.c 
b/kernel/cobalt/arch/powerpc/thread.c
index 2a61d50..e3be67f 100644
--- a/kernel/cobalt/arch/powerpc/thread.c
+++ b/kernel/cobalt/arch/powerpc/thread.c
@@ -92,7 +92,7 @@ static void xnarch_enable_fpu(struct xnthread *thread)
__asm_enable_fpu();
 }
 
-void xnarch_save_fpu(struct xnthread *thread)
+static void do_save_fpu(struct xnthread *thread)
 {
struct xnarchtcb *tcb = xnthread_archtcb(thread);
 
@@ -145,7 +145,7 @@ void xnarch_switch_fpu(struct xnthread *from, struct 
xnthread *to)
}

if (from)
-   xnarch_save_fpu(from);
+   do_save_fpu(from);

xnarch_restore_fpu(to);
 }
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
 {
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
    /* So that xnarch_save_fpu() will operate on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;
 }


___
Xenomai-git mailing list
Xenomai-git@xenomai.org
https://xenomai.org/mailman/listinfo/xenomai-git


[Xenomai-git] Philippe Gerum : cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

2016-09-11 Thread git repository hosting
Module: xenomai-3
Branch: stable-3.0.x
Commit: 2856ff3c0c6199352fac11b4c6dab07a6e8b7b3b
URL:
http://git.xenomai.org/?p=xenomai-3.git;a=commit;h=2856ff3c0c6199352fac11b4c6dab07a6e8b7b3b

Author: Philippe Gerum 
Date:   Thu Sep  8 16:29:44 2016 +0200

cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

---

 kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h |2 --
 kernel/cobalt/arch/powerpc/thread.c |6 +++---
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
-   /* So that xnarch_save_fpu() will operate on the right FPU area. */
+   /* So that do_save_fpu() operates on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;
 2 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/kernel/cobalt/arch/powerpc/thread.c 
b/kernel/cobalt/arch/powerpc/thread.c
index 2a61d50..e3be67f 100644
--- a/kernel/cobalt/arch/powerpc/thread.c
+++ b/kernel/cobalt/arch/powerpc/thread.c
@@ -92,7 +92,7 @@ static void xnarch_enable_fpu(struct xnthread *thread)
__asm_enable_fpu();
 }
 
-void xnarch_save_fpu(struct xnthread *thread)
+static void do_save_fpu(struct xnthread *thread)
 {
struct xnarchtcb *tcb = xnthread_archtcb(thread);
 
@@ -145,7 +145,7 @@ void xnarch_switch_fpu(struct xnthread *from, struct 
xnthread *to)
}

if (from)
-   xnarch_save_fpu(from);
+   do_save_fpu(from);

xnarch_restore_fpu(to);
 }
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
 {
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
    /* So that xnarch_save_fpu() will operate on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;
 }


___
Xenomai-git mailing list
Xenomai-git@xenomai.org
https://xenomai.org/mailman/listinfo/xenomai-git


[Xenomai-git] Philippe Gerum : cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

2016-09-11 Thread git repository hosting
Module: xenomai-3
Branch: next
Commit: 9a28f7c11241971aa7a3c2ebed43018bd2b44075
URL:
http://git.xenomai.org/?p=xenomai-3.git;a=commit;h=9a28f7c11241971aa7a3c2ebed43018bd2b44075

Author: Philippe Gerum 
Date:   Thu Sep  8 16:29:44 2016 +0200

cobalt/powerpc: fpu: drop obsolete xnarch_save_fpu()

---

 kernel/cobalt/arch/powerpc/include/asm/xenomai/thread.h |2 --
 kernel/cobalt/arch/powerpc/thread.c |6 +++---
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
-   /* So that xnarch_save_fpu() will operate on the right FPU area. */
+   /* So that do_save_fpu() operates on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;
 2 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/kernel/cobalt/arch/powerpc/thread.c 
b/kernel/cobalt/arch/powerpc/thread.c
index 2a61d50..e3be67f 100644
--- a/kernel/cobalt/arch/powerpc/thread.c
+++ b/kernel/cobalt/arch/powerpc/thread.c
@@ -92,7 +92,7 @@ static void xnarch_enable_fpu(struct xnthread *thread)
__asm_enable_fpu();
 }
 
-void xnarch_save_fpu(struct xnthread *thread)
+static void do_save_fpu(struct xnthread *thread)
 {
struct xnarchtcb *tcb = xnthread_archtcb(thread);
 
@@ -145,7 +145,7 @@ void xnarch_switch_fpu(struct xnthread *from, struct 
xnthread *to)
}

if (from)
-   xnarch_save_fpu(from);
+   do_save_fpu(from);

xnarch_restore_fpu(to);
 }
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
 {
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
    /* So that xnarch_save_fpu() will operate on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;
 }
@@ -154,7 +154,7 @@ void xnarch_leave_root(struct xnthread *root)
struct xnarchtcb *rootcb = xnthread_archtcb(root);
rootcb->core.user_fpu_owner = get_fpu_owner(rootcb->core.host_task);
-   /* So that xnarch_save_fpu() will operate on the right FPU area. */
+   /* So that do_save_fpu() operates on the right FPU area. */
rootcb->fpup = rootcb->core.user_fpu_owner ?
>core.user_fpu_owner->thread : NULL;


___
Xenomai-git mailing list
Xenomai-git@xenomai.org
https://xenomai.org/mailman/listinfo/xenomai-git